---
gitea: none
include_toc: true
---

# Variables
## HTTP(s) proxy server overview and configuration (env_proxy)

A proxy server acts as an intermediary gateway between a client and another
HTTP(s) server, such as the Internet.

It makes service requests on behalf of a local client and allows the client
to make network connections to network services outside its own network.


| Parameter                                                                                                                                                                                                                                                  | Comment                                                                                                                                                                                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **host**<br/>`mandatory`<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                          | The proxy server’s address.<br/>Specifies the hostname of proxy server to enable proxy server access to all of your HTTP(s) requests. .<br/>**Example:** proxy.silique.fr                                                                                  |
| **port**<br/>`mandatory`<br/>**Type:** [`port`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                                | The proxy server's port.<br/>**Default:** 3128                                                                                                                                                                                                             |
| **no_proxy**<br/>`multiple`<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                       | Exclude proxy server.<br/>Network address(es), network address range(s) and domains to exclude from using the proxy when initiating connection(s). .<br/>**Examples:** 192.168.1.1, 192.168.10.0/24, www.silique.fr, .internal.silique.fr                  |

## Apero service (env_apero)

### Add access informations to Apero service (env_apero.access)

To access to Apero service, other services need an account and
a password.


This family is a leadership.

| Parameter                                                                                                                                                                                                                                                  | Comment                                                                                                                                                                                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **login**<br/>`mandatory`, `multiple`<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                              | Login name.<br/>The account name is typically the name of foreign services. .<br/>**Example:** srep                                                                                                                                                        |
| **password**<br/>`mandatory`<br/>**Type:** [`secret`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                          | Password.                                                                                                                                                                                                                                                  |

## SREP service (env_srep)

| Parameter                                                                                                                                                                                                                                                  | Comment                                                                                                                                                                                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **apero_user**<br/>`mandatory`<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                        | Account to access to Apero service.<br/>**Choices:** see variable "env_apero.access.login"<br/>**Example:** srep                                                                                                                                           |

## Configure OMOGEN (env_omogen)

| Parameter                                                                                                                                                                                                                                                  | Comment                                                                                                                                                                                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **keystore**<br/>`mandatory`<br/>**Type:** [`string`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                          | Keystore filename to access to OMOGEN.<br/>This filename must ends with "kjs" extension.<br/>**Example:** java.jks                                                                                                                                         |

## NFS configuration (env_nfs)

| Parameter                                                                                                                                                                                                                                                  | Comment                                                                                                                                                                                                                                                    |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **configure**<br/>`mandatory`<br/>**Type:** [`boolean`](https://forge.cloud.silique.fr/stove/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                                                                                        | Configure NFS mount.<br/>To share documents between differents services, you need to configure a NFS server .<br/>**Default:** False                                                                                                                       |

# Example with mandatories variables

```
env_proxy:
  host: proxy.silique.fr
env_apero:
  access:
  - login: srep
    password: xxx
env_srep:
  apero_user: srep
env_omogen:
  keystore: java.jks
```

# Example with all variables

```
env_proxy:
  host: proxy.silique.fr
  port: '3128'
  no_proxy:
  - 192.168.1.1
  - 192.168.10.0/24
  - www.silique.fr
  - .internal.silique.fr
env_apero:
  access:
  - login: srep
    password: xxx
env_srep:
  apero_user: srep
env_omogen:
  keystore: java.jks
env_nfs:
  configure: false
```
